@@ -87,7 +87,8 @@ setMethod("[", "SpatialPolygonsDataFrame", function(x, i, j, ... , drop = TRUE)
         stop("matrix argument not supported in SpatialPolygonsDataFrame selection")
 	if (is(i, "Spatial"))
 		i = !is.na(over(x, geometry(i)))
-    if (any(is.na(i))) stop("NAs not permitted in row index")
+    if (any(is.na(i)))
+		stop("NAs not permitted in row index")
     #SpatialPolygonsDataFrame(as(x, "SpatialPolygons")[i, , drop = FALSE],
     #    data = x@data[i, j, drop = FALSE], match.ID = FALSE)
         y <- new("SpatialPolygonsDataFrame")
