@@ -13,7 +13,6 @@ SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP ihole) {
     SEXP valid;
 
     SP_PREFIX(spRFindCG_c)(n, coords, &xc, &yc, &area);
-
     if (abs(area) < DOUBLE_EPS) {
         if (!R_FINITE(xc) || !R_FINITE(xc)) {
             if (nn == 1) {
@@ -35,6 +34,7 @@ SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP ihole) {
 
     PROTECT(ringDir = NEW_INTEGER(1)); pc++;
     INTEGER_POINTER(ringDir)[0] = (area > 0.0) ? -1 : 1;
+// -1 cw hole, 1 ccw not-hole
 
 /* RSB 100126 fixing hole assumption
  thanks to Javier Munoz for report */
@@ -57,7 +57,6 @@ SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP ihole) {
             INTEGER_POINTER(ringDir)[0] = 1;
         }
     }
-
     PROTECT(hole = NEW_LOGICAL(1)); pc++;
     if (INTEGER_POINTER(ihole)[0] == 1) LOGICAL_POINTER(hole)[0] = TRUE;
     else LOGICAL_POINTER(hole)[0] = FALSE;
@@ -163,6 +162,7 @@ SEXP SP_PREFIX(Polygons_c)(SEXP pls, SEXP ID) {
     } else {
         po[0] = 1;
     }
+
     if (sumholes == nps) {
         crds = GET_SLOT(VECTOR_ELT(pls, (po[0] - R_OFFSET)), install("coords"));
         PROTECT(n = NEW_INTEGER(1)); pc++;
@@ -182,8 +182,9 @@ SEXP SP_PREFIX(Polygons_c)(SEXP pls, SEXP ID) {
 
     PROTECT(Area = NEW_NUMERIC(1)); pc++;
     NUMERIC_POINTER(Area)[0] = 0.0;
-    for (i=0; i<nps; i++) 
+    for (i=0; i<nps; i++) {
         NUMERIC_POINTER(Area)[0] += holes[i] ? 0.0 : fabs(areas[i]);
+    }
     SET_SLOT(ans, install("area"), Area);
 
     PROTECT(plotOrder = NEW_INTEGER(nps)); pc++;
@@ -463,8 +464,8 @@ double     SP_PREFIX(Area2)( tPointd a, tPointd b, tPointd c )
 
 SEXP SP_PREFIX(comment2comm)(SEXP obj) {
     SEXP ans, comment;
-    int pc=0, ns, i, j, jj, k;
-    char buf[BUFSIZE], s[15];
+    int pc=0, ns, i, j, jj, k, nc;
+    char s[15], *buf;
     int *c, *nss, *co, *coo;
 
     PROTECT(comment = getAttrib(obj, install("comment"))); pc++;
@@ -472,6 +473,10 @@ SEXP SP_PREFIX(comment2comm)(SEXP obj) {
         UNPROTECT(pc);
         return(R_NilValue);
     }
+
+    nc = length(STRING_ELT(comment, 0));
+    buf = (char *) R_alloc((size_t) (nc+1), sizeof(char));
+
     strcpy(buf, CHAR(STRING_ELT(comment, 0)));
 
     i = 0;
@@ -539,15 +544,22 @@ SEXP SP_PREFIX(comment2comm)(SEXP obj) {
     return(ans);
 }
 
-void SP_PREFIX(comm2comment)(char *buf, int *comm, int nps) {
+void SP_PREFIX(comm2comment)(char *buf, int bufsiz, int *comm, int nps) {
     char cbuf[15];
-    int i;
+    int i, nc, nc1;
+
+    nc = ceil(log10(nps)+1)+1;
+    nc1 = (nc*nps)+1;
+    if (bufsiz < nc1) error("comm2comment: buffer overflow");
 
     sprintf(buf, "%d", comm[0]);
     for (i=1; i<nps; i++) {
         sprintf(cbuf, " %d", comm[i]);
+        if (strlen(buf) + strlen(cbuf) >= bufsiz)
+            error("comm2comment: buffer overflow");
         strcat(buf, cbuf);
     }
+    strcat(buf, "\0");
     return;
 }
 
